bootSeed property
Uint8List?
get
bootSeed
A random value unique to the current boot cycle (key 268), the same in every token of one boot cycle.
Implementation
Uint8List? get bootSeed => _asBytes(_map[268]);
set
bootSeed
(Uint8List? value)
Implementation
set bootSeed(Uint8List? value) => _set(268, value);