DebugState enum
Debug port state per RFC 9711 Section 4.2.9.
Values
- enabled → const DebugState
-
Debug is currently enabled.
- disabled → const DebugState
-
Debug is currently disabled.
- disabledSinceBoot → const DebugState
-
Debug was disabled at boot and has not been enabled since.
- disabledPermanently → const DebugState
-
Debug is disabled and cannot be re-enabled.
- disabledFullyPermanently → const DebugState
-
All debug, including DMA-based, is permanently disabled.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
DebugState> - A constant List of the values in this enum, in order of their declaration.