Fingerprint class

A 256-bit unique identifier for an RSA key, the SHA256 hash of its raw public key in little-endian format (modulus || exponent).

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Converts a fingerprint into a 32-byte array.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Whether other is an RSA fingerprint with the same bytes.
override

Static Methods

fromBytes(Uint8List bytes) → Fingerprint
Creates a fingerprint from a 32-byte array.