PublicKey class
A 2048-bit RSA public key usable for verification, with SHA256 as the underlying hash algorithm. Whilst RSA could also be used for decryption, that is not exposed on the API as it's not required by the project.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fingerprint(
) → Fingerprint - Returns a 256-bit unique identifier for this key. For RSA, that is the SHA256 hash of the raw (le modulus || le exponent) public key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List - Serializes a public key into a 264-byte array.
-
toDer(
) → Uint8List - Serializes a public key into a DER buffer.
-
toPem(
) → String - Serializes a public key into a PEM string.
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Uint8List message, Signature signature) → void - Verifies a signature against a message.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited