decrypt function

Uint8List decrypt({
  1. required Uint8List key,
  2. required Uint8List ciphertext,
})

Decrypts a STREAM ciphertext under the 32-byte key it was encrypted with.

Throws if key is not 32 bytes long, or if the ciphertext does not authenticate under it, such as when it was truncated, reordered or tampered with.

Implementation

Uint8List decrypt({required Uint8List key, required Uint8List ciphertext}) =>
    ffi.streamDecrypt(key: key, ciphertext: ciphertext);