PublicKey class

An ML-DSA-65 public key paired with an Ed25519 public key for verifying quantum resistant digital signatures.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

fingerprint() → Fingerprint
Returns a 256-bit unique identifier for this key.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Converts a public key into a 1984-byte array.
toDer() → Uint8List
Serializes a public key into a DER buffer.
toPem() → String
Serializes a public key into a PEM string.
toString() → String
A string representation of this object.
inherited
verify(Uint8List message, Signature signature) → void
Verifies a signature against a message.

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(Uint8List bytes) → PublicKey
Converts a 1984-byte array into a public key, the ML-DSA-65 key (1952 bytes) followed by the Ed25519 key (32 bytes).
fromDer(Uint8List der) → PublicKey
Parses a DER buffer into a public key.
fromPem(String pem) → PublicKey
Parses a PEM string into a public key.