verify method

void verify(
  1. Uint8List message,
  2. Signature signature
)

Verifies a signature against a message.

Throws if the signature does not verify under this key for message. Either half failing is enough, and the two cases are not told apart.

Implementation

void verify(Uint8List message, Signature signature) =>
    _inner.verify(message: message, signature: signature._inner);