Signature class

An ML-DSA-65 signature (3309 bytes) paired with an Ed25519 signature (64 bytes), 3373 bytes in total.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toBytes() → Uint8List
Converts the signature into a 3373-byte array.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromBytes(Uint8List bytes) → Signature
Creates a signature from a 3373-byte array.