open method
Decrypts a message using the next nonce in the sequence.
Implementation
Uint8List open({
required Uint8List msgToOpen,
required Uint8List msgToAuth,
}) => _inner.open(msgToOpen: msgToOpen, msgToAuth: msgToAuth);
Decrypts a message using the next nonce in the sequence.
Uint8List open({
required Uint8List msgToOpen,
required Uint8List msgToAuth,
}) => _inner.open(msgToOpen: msgToOpen, msgToAuth: msgToAuth);