IntendedUse enum
Token intended purpose per RFC 9711 Section 4.3.3.
Values
- generic → const IntendedUse
-
General-purpose attestation.
- registration → const IntendedUse
-
Attestation for service registration.
- provisioning → const IntendedUse
-
Attestation prior to key/config provisioning.
- certIssuance → const IntendedUse
-
Attestation for certificate signing requests.
- proofOfPossession → const IntendedUse
-
Attestation accompanying a proof-of-possession.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
IntendedUse> - A constant List of the values in this enum, in order of their declaration.