PublicKey class
An ML-DSA-65 public key paired with an Ed25519 public key for verifying quantum resistant digital signatures.
- Available extensions
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- inner → XdsaPublicKey
-
Available on PublicKey, provided by the PublicKeyInternal extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fingerprint(
) → Fingerprint - Returns a 256-bit unique identifier for this key.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toBytes(
) → Uint8List - Converts a public key into a 1984-byte array.
-
toDer(
) → Uint8List - Serializes a public key into a DER buffer.
-
toPem(
) → String - Serializes a public key into a PEM string.
-
toString(
) → String -
A string representation of this object.
inherited
-
verify(
Uint8List message, Signature signature) → void - Verifies a signature against a message.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited