PublicKey class

A public key of the X-Wing hybrid KEM (X25519 + ML-KEM-768).

Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
inner → XhpkePublicKey

Available on PublicKey, provided by the PublicKeyInternal extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

fingerprint() Fingerprint
Returns a 256-bit unique identifier for this key. For HPKE, that is the SHA256 hash of the raw public key.
newSender({required Uint8List domain}) → (Sender, Uint8List)
Creates an HPKE sender context for multi-message encryption.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
seal({required Uint8List msgToSeal, required Uint8List msgToAuth, required Uint8List domain}) → (Uint8List, Uint8List)
Encrypts a message to this public key.
toBytes() Uint8List
Converts a public key into a 1216-byte array.
toDer() Uint8List
Serializes a public key into a DER buffer.
toPem() String
Serializes a public key into a PEM string.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromBytes(Uint8List bytes) PublicKey
Converts a 1216-byte array into a public key.
fromDer(Uint8List der) PublicKey
Parses a DER buffer into a public key.
fromPem(String pem) PublicKey
Parses a PEM string into a public key.