Receiver class
A stateful HPKE receiver context for multi-message decryption.
Each call to open decrypts a message using an auto-incrementing nonce. Messages must be provided in the same order they were sealed by the corresponding Sender.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
open(
{required Uint8List msgToOpen, required Uint8List msgToAuth}) → Uint8List - Decrypts a message using the next nonce in the sequence.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited